@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVIDIA Corporation
+    Copyright (c) 2015-2019 NVIDIA Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -200,6 +200,10 @@ struct uvm_page_table_range_vec_struct
 // Called at module init
 NV_STATUS uvm_mmu_init(void);
 
+// Initialize MMU-specific information for the GPU, including GPU's peer
+// mappings
+void uvm_mmu_init_gpu(uvm_gpu_t *gpu);
+
 // Create a page tree structure and allocate the root directory. location
 // behavior:
 // - UVM_APERTURE_VID       Force all page table allocations into vidmem
@@ -295,7 +299,10 @@ void uvm_page_tree_put_ptes_async(uvm_page_tree_t *tree, uvm_page_table_range_t
 NV_STATUS uvm_page_tree_wait(uvm_page_tree_t *tree);
 
 // Returns the physical allocation that contains the root directory
-uvm_mmu_page_table_alloc_t *uvm_page_tree_pdb(uvm_page_tree_t *tree);
+static uvm_mmu_page_table_alloc_t *uvm_page_tree_pdb(uvm_page_tree_t *tree)
+{
+    return &tree->root->phys_alloc;
+}
 
 // Initialize a page table range vector covering the specified VA range [start, start + size)
 //
@@ -341,13 +348,6 @@ NV_STATUS uvm_page_table_range_vec_write_ptes(uvm_page_table_range_vec_t *range_
 // membar.
 NV_STATUS uvm_page_table_range_vec_clear_ptes(uvm_page_table_range_vec_t *range_vec, uvm_membar_t tlb_membar);
 
-// Returns a bitmap of allocation sizes that could be requested by the page tree for a GPU
-uvm_chunk_sizes_mask_t uvm_mmu_kernel_chunk_sizes(uvm_gpu_t *gpu);
-
-// Returns a bitmap of allocation sizes for user memory supported by a GPU.
-// PAGE_SIZE is guaranteed to be both present and the smallest size.
-uvm_chunk_sizes_mask_t uvm_mmu_user_chunk_sizes(uvm_gpu_t *gpu);
-
 // Create the necessary big page identity mappings for the GPU
 NV_STATUS uvm_mmu_create_big_page_identity_mappings(uvm_gpu_t *gpu);
 
@@ -365,9 +365,6 @@ void uvm_mmu_destroy_peer_identity_mappings(uvm_gpu_t *gpu, uvm_gpu_t *peer);
 // return the address as-is.
 uvm_gpu_address_t uvm_mmu_gpu_address_for_big_page_physical(uvm_gpu_address_t physical, uvm_gpu_t *gpu);
 
-// Helper for initializing a GPU's peer VA space
-void uvm_mmu_init_gpu_peer_addresses(uvm_gpu_t *gpu);
-
 static NvU64 uvm_mmu_page_tree_entries(uvm_page_tree_t *tree, NvU32 depth, NvU32 page_size)
 {
     return 1ull << tree->hal->index_bits(depth, page_size);
